@@ -1,8 +1,7 @@
-// $Id: x01c.c 12288 2013-01-30 04:40:35Z airwin $
-//
 //      Simple line plot and multiple windows demo.
 //
-// Copyright (C) 2004  Rafael Laboissiere
+// Copyright (C) 2004 Rafael Laboissiere
+// Copyright (C) 2000-2018 Alan W. Irwin
 //
 // This file is part of PLplot.
 //
@@ -24,6 +23,9 @@
 
 #include "plcdemos.h"
 #include "plevent.h"
+#ifdef PL_HAVE_NANOSLEEP
+#include <time.h>
+#endif
 #ifdef PL_HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -37,11 +39,21 @@ static PLGraphicsIn gin;
 static int          locate_mode;
 static int          test_xor;
 static int          fontset = 1;
+static int          pl_parse_skip_mode;
 static char         *f_name = NULL;
 
 // Options data structure definition.
 
 static PLOptionTable options[] = {
+    {
+        "pl_parse_skip",
+        NULL,
+        NULL,
+        &pl_parse_skip_mode,
+        PL_OPT_BOOL,
+        "-pl_parse_skip",
+        "Test using PL_PARSE_SKIP mode for plparseopts (this option must precede non-PLplot options)"
+    },
     {
         "locate",               // Turns on test of API locate function
         NULL,
@@ -89,7 +101,7 @@ static PLOptionTable options[] = {
     }                           // long syntax
 };
 
-const char           *notes[] = { "Make sure you get it right!", NULL };
+PLCHAR_VECTOR        notes[] = { "Make sure you get it right!", NULL };
 
 // Function prototypes
 
@@ -110,17 +122,41 @@ void plot3( void );
 //--------------------------------------------------------------------------
 
 int
-main( int argc, const char *argv[] )
+main( int argc, char *argv[] )
 {
     PLINT digmax, cur_strm, new_strm;
     char  ver[80];
+    PLINT i;
 
 // plplot initialization
 
 // Parse and process command line arguments
 
     plMergeOpts( options, "x01c options", notes );
-    plparseopts( &argc, argv, PL_PARSE_FULL );
+    // See if -pl_parse_skip has been specified without
+    // changing argc or argv
+    plparseopts( &argc, argv, PL_PARSE_NODELETE );
+    if ( pl_parse_skip_mode )
+    {
+        printf( "argv prior to call of plparseopts(..., PL_PARSE_SKIP)\n" );
+        for ( i = 0; i < argc; i++ )
+        {
+            printf( "i = %3d, argument = %s\n", i, argv[i] );
+        }
+        plparseopts( &argc, argv, PL_PARSE_SKIP );
+        printf( "argv after call to plparseopts(..., PL_PARSE_SKIP)\n" );
+        for ( i = 0; i < argc; i++ )
+        {
+            printf( "i = %3d, argument = %s\n", i, argv[i] );
+        }
+    }
+    else
+    {
+        // parse the command line again, and after such parsing
+        // argc and argv are typically reduced to 1 and the name
+        // of the programme that is being executed.
+        plparseopts( &argc, argv, PL_PARSE_FULL );
+    }
 
 // Get version number, just for kicks
 
@@ -203,13 +239,10 @@ main( int argc, const char *argv[] )
                 break;
 
             pltext();
-            if ( gin.keysym < 0xFF && isprint( gin.keysym ) )
-                printf( "subwin = %d, wx = %f,  wy = %f, dx = %f,  dy = %f,  c = '%c' s = '%s'\n",
-                    gin.subwindow, gin.wX, gin.wY, gin.dX, gin.dY, gin.keysym, gin.string );
-            else
-                printf( "subwin = %d, wx = %f,  wy = %f, dx = %f,  dy = %f,  c = 0x%02x s - '%s'\n",
-                    gin.subwindow, gin.wX, gin.wY, gin.dX, gin.dY, gin.keysym, gin.string );
-
+            printf( "subwin = %d, wx = %f,  wy = %f, dx = %f,  dy = %f\n",
+                gin.subwindow, gin.wX, gin.wY, gin.dX, gin.dY );
+            printf( "keysym = 0x%02x, button = 0x%02x, string = '%s', type = 0x%02x, state = 0x%02x\n",
+                gin.keysym, gin.button, gin.string, gin.type, gin.state );
             plgra();
         }
     }
@@ -270,15 +303,18 @@ plot1( int do_test )
 
     if ( do_test && test_xor )
     {
-#ifdef PL_HAVE_USLEEP
-        PLINT st;
+#ifdef PL_HAVE_NANOSLEEP
+        PLINT           st;
+        struct timespec ts;
+        ts.tv_sec  = 0;
+        ts.tv_nsec = 50000000;
         plxormod( 1, &st ); // enter xor mode
         if ( st )
         {
             for ( i = 0; i < 60; i++ )
             {
                 plpoin( 1, x + i, y + i, 9 );   // draw a point
-                usleep( 50000 );                // wait a little
+                nanosleep( &ts, NULL );         // wait a little
                 plflush();                      // force an update of the tk driver
                 plpoin( 1, x + i, y + i, 9 );   // erase point
             }
@@ -286,7 +322,7 @@ plot1( int do_test )
         }
 #else
         printf( "The -xor command line option can only be exercised if your "
-            "system\nhas usleep(), which does not seem to happen.\n" );
+            "system\nhas nanosleep(), which does not seem to happen.\n" );
 #endif
     }
 }
