@@ -1,7 +1,3 @@
-// -*- coding: utf-8; -*-
-//
-// $Id: x26c.c 12319 2013-05-01 21:51:24Z airwin $
-//
 // Multi-lingual version of the first page of example 4.
 //
 // Copyright (C) 2006 Alan Irwin
@@ -64,45 +60,45 @@
 
 #include "plcdemos.h"
 
-static const char *x_labels[] = {
+static PLCHAR_VECTOR x_labels[] = {
     "Frequency",
     "Частота",
     NULL
 };
 
-static const char *y_labels[] = {
+static PLCHAR_VECTOR y_labels[] = {
     "Amplitude (dB)",
     "Амплитуда (dB)",
     NULL
 };
 
-static const char *alty_labels[] = {
+static PLCHAR_VECTOR alty_labels[] = {
     "Phase shift (degrees)",
     "Фазовый сдвиг (градусы)",
     NULL
 };
 
 // Short rearranged versions of y_label and alty_label.
-static const char *legend_texts[][2] = {
-    { "Amplitude",          "Phase shift"               },
+static PLCHAR_VECTOR legend_texts[][2] = {
+    { "Amplitude", "Phase shift"   },
     { "Амплитуда", "Фазовый сдвиг" }
 };
 
-static const char *title_labels[] = {
+static PLCHAR_VECTOR title_labels[] = {
     "Single Pole Low-Pass Filter",
     "Однополюсный Низко-Частотный Фильтр",
     NULL
 };
 
-static const char *line_labels[] = {
+static PLCHAR_VECTOR line_labels[] = {
     "-20 dB/decade",
     "-20 dB/десяток",
     NULL
 };
 
-void plot1( int type, const char *x_label, const char *y_label,
-            const char *alty_label, const char * legend_text[],
-            const char *title_label, const char *line_label );
+void plot1( int type, PLCHAR_VECTOR x_label, PLCHAR_VECTOR y_label,
+            PLCHAR_VECTOR alty_label, PLCHAR_VECTOR legend_text[],
+            PLCHAR_VECTOR title_label, PLCHAR_VECTOR line_label );
 
 //--------------------------------------------------------------------------
 // main
@@ -111,7 +107,7 @@ void plot1( int type, const char *x_label, const char *y_label,
 //--------------------------------------------------------------------------
 
 int
-main( int argc, const char *argv[] )
+main( int argc, char *argv[] )
 {
     int i;
 // Parse and process command line arguments
@@ -144,22 +140,22 @@ main( int argc, const char *argv[] )
 //--------------------------------------------------------------------------
 
 void
-plot1( int type, const char *x_label, const char *y_label, const char *alty_label,
-       const char * legend_text[], const char *title_label, const char *line_label )
+plot1( int type, PLCHAR_VECTOR x_label, PLCHAR_VECTOR y_label, PLCHAR_VECTOR alty_label,
+       PLCHAR_VECTOR legend_text[], PLCHAR_VECTOR title_label, PLCHAR_VECTOR line_label )
 {
-    int          i;
-    static PLFLT freql[101], ampl[101], phase[101];
-    PLFLT        f0, freq;
-    PLINT        nlegend = 2;
-    PLINT        opt_array[2];
-    PLINT        text_colors[2];
-    PLINT        line_colors[2];
-    PLINT        line_styles[2];
-    PLFLT        line_widths[2];
-    PLINT        symbol_numbers[2], symbol_colors[2];
-    PLFLT        symbol_scales[2];
-    const char   *symbols[2];
-    PLFLT        legend_width, legend_height;
+    int           i;
+    static PLFLT  freql[101], ampl[101], phase[101];
+    PLFLT         f0, freq;
+    PLINT         nlegend = 2;
+    PLINT         opt_array[2];
+    PLINT         text_colors[2];
+    PLINT         line_colors[2];
+    PLINT         line_styles[2];
+    PLFLT         line_widths[2];
+    PLINT         symbol_numbers[2], symbol_colors[2];
+    PLFLT         symbol_scales[2];
+    PLCHAR_VECTOR symbols[2];
+    PLFLT         legend_width, legend_height;
 
 
     pladv( 0 );
@@ -215,7 +211,7 @@ plot1( int type, const char *x_label, const char *y_label, const char *alty_labe
         plbox( "", 0.0, 0, "cmstv", 30.0, 3 );
         plcol0( 3 );
         plline( 101, freql, phase );
-        plstring( 101, freql, phase, "*" );
+        plstring( 101, freql, phase, "#(728)" );
         plcol0( 3 );
         plmtex( "r", 5.0, 0.5, 0.5, alty_label );
     }
@@ -238,7 +234,7 @@ plot1( int type, const char *x_label, const char *y_label, const char *alty_labe
     symbol_colors[1]  = 3;
     symbol_scales[1]  = 1.;
     symbol_numbers[1] = 4;
-    symbols[1]        = "*";
+    symbols[1]        = "#(728)";
     // from the above opt_arrays we can completely ignore everything
     // to do with boxes.
 
