@@ -1,5 +1,3 @@
-// $Id: x29c.c 12213 2012-08-14 07:03:04Z andrewross $
-//
 //     Sample plots using date / time formatting for axes
 //
 // Copyright (C) 2007 Andrew Ross
@@ -55,7 +53,7 @@ void plot4( void );
 //--------------------------------------------------------------------------
 
 int
-main( int argc, const char *argv[] )
+main( int argc, char *argv[] )
 {
     // Parse command line arguments
     plparseopts( &argc, argv, PL_PARSE_FULL );
@@ -234,10 +232,8 @@ void
 plot4( void )
 {
     // TAI-UTC (seconds) as a function of time.
-    // Use Besselian epochs as the continuous time interval just to prove
-    // this does not introduce any issues.
 
-    PLFLT scale, offset1, offset2;
+    PLFLT scale;
     PLFLT xmin, xmax, ymin = 0.0, ymax = 0.0, xlabel_step = 0.0;
     int   kind, npts = 0, if_TAI_time_format = 0, i;
     char  time_format[10];
@@ -245,26 +241,54 @@ plot4( void )
     char  xtitle[100];
     char  title[100];
     PLFLT xx[1001], yy[1001];
+    PLINT epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min;
+    PLFLT epoch_sec;
     PLINT tai_year, tai_month, tai_day, tai_hour, tai_min;
     PLFLT tai_sec, tai;
     PLINT utc_year, utc_month, utc_day, utc_hour, utc_min;
     PLFLT utc_sec, utc;
 
-    // Use the definition given in http://en.wikipedia.org/wiki/Besselian_epoch
-    // B = 1900. + (JD -2415020.31352)/365.242198781
-    // ==> (as calculated with aid of "bc -l" command)
-    // B = (MJD + 678940.364163900)/365.242198781
-    // ==>
-    // MJD = B*365.24219878 - 678940.364163900
-    scale   = 365.242198781;
-    offset1 = -678940.;
-    offset2 = -0.3641639;
-    plconfigtime( scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0. );
+    // Continuous time unit is Besselian years from whatever epoch is
+    // chosen below.  Could change to seconds (or days) from the
+    // epoch, but then would have to adjust xlabel_step below.
+    scale = 365.242198781;
+    // MJD epoch (see <https://en.wikipedia.org/wiki/Julian_day>).
+    // This is only set for illustrative purposes, and is overwritten
+    // below for the time-representation reasons given in the
+    // discussion below.
+    epoch_year  = 1858;
+    epoch_month = 11;
+    epoch_day   = 17;
+    epoch_hour  = 0;
+    epoch_min   = 0;
+    epoch_sec   = 0.;
+    // To illustrate the time-representation issues of using the MJD
+    // epoch, in 1985, MJD was roughly 46000 days which corresponds to
+    // 4e9 seconds.  Thus, for the -DPL_DOUBLE=ON case where PLFLT is
+    // a double which can represent continuous time to roughly 16
+    // decimal digits of precision the time-representation error is
+    // roughly ~400 nanoseconds.  Therefore the MJD epoch would be
+    // acceptable for the plots below in the -DPL_DOUBLE=ON case.
+    // However, that epoch is obviously not acceptable for the
+    // -DPL_DOUBLE=OFF case where PLFLT is a float which can represent
+    // continuous time to only ~7 decimal digits of precision
+    // corresponding to a time representation error of 400 seconds (!)
+    // in 1985.  For this reason, we do not use the MJD epoch below
+    // and instead choose the best epoch for each case to minimize
+    // time-representation issues.
 
     for ( kind = 0; kind < 7; kind++ )
     {
         if ( kind == 0 )
         {
+            // Choose midpoint to maximize time-representation precision.
+            epoch_year  = 1985;
+            epoch_month = 0;
+            epoch_day   = 2;
+            epoch_hour  = 0;
+            epoch_min   = 0;
+            epoch_sec   = 0.;
+            plconfigtime( scale, 0., 0., 0x0, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
             plctime( 1950, 0, 2, 0, 0, 0., &xmin );
             plctime( 2020, 0, 2, 0, 0, 0., &xmax );
             npts = 70 * 12 + 1;
@@ -278,6 +302,14 @@ plot4( void )
         }
         else if ( kind == 1 || kind == 2 )
         {
+            // Choose midpoint to maximize time-representation precision.
+            epoch_year  = 1961;
+            epoch_month = 7;
+            epoch_day   = 1;
+            epoch_hour  = 0;
+            epoch_min   = 0;
+            epoch_sec   = 1.64757;
+            plconfigtime( scale, 0., 0., 0x0, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
             plctime( 1961, 7, 1, 0, 0, 1.64757 - .20, &xmin );
             plctime( 1961, 7, 1, 0, 0, 1.64757 + .20, &xmax );
             npts = 1001;
@@ -299,6 +331,14 @@ plot4( void )
         }
         else if ( kind == 3 || kind == 4 )
         {
+            // Choose midpoint to maximize time-representation precision.
+            epoch_year  = 1963;
+            epoch_month = 10;
+            epoch_day   = 1;
+            epoch_hour  = 0;
+            epoch_min   = 0;
+            epoch_sec   = 2.6972788;
+            plconfigtime( scale, 0., 0., 0x0, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
             plctime( 1963, 10, 1, 0, 0, 2.6972788 - .20, &xmin );
             plctime( 1963, 10, 1, 0, 0, 2.6972788 + .20, &xmax );
             npts = 1001;
@@ -320,6 +360,14 @@ plot4( void )
         }
         else if ( kind == 5 || kind == 6 )
         {
+            // Choose midpoint to maximize time-representation precision.
+            epoch_year  = 2009;
+            epoch_month = 0;
+            epoch_day   = 1;
+            epoch_hour  = 0;
+            epoch_min   = 0;
+            epoch_sec   = 34.;
+            plconfigtime( scale, 0., 0., 0x0, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
             plctime( 2009, 0, 1, 0, 0, 34. - 5., &xmin );
             plctime( 2009, 0, 1, 0, 0, 34. + 5., &xmax );
             npts = 1001;
@@ -342,14 +390,21 @@ plot4( void )
 
         for ( i = 0; i < npts; i++ )
         {
-            xx[i] = xmin + i * ( xmax - xmin ) / ( (double) ( npts - 1 ) );
-            plconfigtime( scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0. );
-            tai = xx[i];
+            xx[i] = xmin + i * ( xmax - xmin ) / ( (PLFLT) ( npts - 1 ) );
+            tai   = xx[i];
+            plconfigtime( scale, 0., 0., 0x0, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
             plbtime( &tai_year, &tai_month, &tai_day, &tai_hour, &tai_min, &tai_sec, tai );
-            plconfigtime( scale, offset1, offset2, 0x2, 0, 0, 0, 0, 0, 0, 0. );
+            // Calculate residual using tai as the epoch to nearly maximize time-representation precision.
+            plconfigtime( scale, 0., 0., 0x0, 1, tai_year, tai_month, tai_day, tai_hour, tai_min, tai_sec );
+            // Calculate continuous tai with new epoch.
+            plctime( tai_year, tai_month, tai_day, tai_hour, tai_min, tai_sec, &tai );
+            // Calculate broken-down utc (with leap seconds inserted) from continuous tai with new epoch.
+            plconfigtime( scale, 0., 0., 0x2, 1, tai_year, tai_month, tai_day, tai_hour, tai_min, tai_sec );
             plbtime( &utc_year, &utc_month, &utc_day, &utc_hour, &utc_min, &utc_sec, tai );
-            plconfigtime( scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0. );
+            // Calculate continuous utc from broken-down utc using same epoch as for the continuous tai.
+            plconfigtime( scale, 0., 0., 0x0, 1, tai_year, tai_month, tai_day, tai_hour, tai_min, tai_sec );
             plctime( utc_year, utc_month, utc_day, utc_hour, utc_min, utc_sec, &utc );
+            // Convert residuals to seconds.
             yy[i] = ( tai - utc ) * scale * 86400.;
         }
 
@@ -358,9 +413,9 @@ plot4( void )
         plwind( xmin, xmax, ymin, ymax );
         plcol0( 1 );
         if ( if_TAI_time_format )
-            plconfigtime( scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0. );
+            plconfigtime( scale, 0., 0., 0x0, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
         else
-            plconfigtime( scale, offset1, offset2, 0x2, 0, 0, 0, 0, 0, 0, 0. );
+            plconfigtime( scale, 0., 0., 0x2, 1, epoch_year, epoch_month, epoch_day, epoch_hour, epoch_min, epoch_sec );
         pltimefmt( time_format );
         plbox( "bcnstd", xlabel_step, 0, "bcnstv", 0., 0 );
         plcol0( 3 );
