@@ -1,10 +1,6 @@
-// -*- coding: utf-8; -*-
-//
-// $Id: x33c.c 12345 2013-05-22 22:40:57Z andrewross $
-//
 // Demonstrate most pllegend capability including unicode symbols.
 //
-// Copyright (C) 2010 Alan Irwin
+// Copyright (C) 2010-2018 Alan Irwin
 //
 // This file is part of PLplot.
 //
@@ -33,7 +29,7 @@
 #include "plcdemos.h"
 
 void plcolorbar_example_page( int kind_i, int label_i, int cap_i, PLINT cont_color, PLFLT cont_width, PLINT n_values, PLFLT *values );
-void plcolorbar_example( const char *palette, int kind_i, PLINT cont_color, PLFLT cont_width, PLINT n_values, PLFLT *values );
+void plcolorbar_example( PLCHAR_VECTOR palette, int kind_i, PLINT cont_color, PLFLT cont_width, PLINT n_values, PLFLT *values );
 
 static PLINT position_options[16] = {
     PL_POSITION_LEFT | PL_POSITION_TOP | PL_POSITION_OUTSIDE,
@@ -55,7 +51,7 @@ static PLINT position_options[16] = {
 };
 
 // Pick 5 arbitrary UTF-8 symbols useful for plotting points (✠✚✱✪✽✺✰✴✦).
-static const char *special_symbols[5] = {
+static PLCHAR_VECTOR special_symbols[5] = {
     "✰",
     "✴",
     "✱",
@@ -67,13 +63,13 @@ static const char *special_symbols[5] = {
 
 // Colorbar type options
 #define COLORBAR_KINDS    4
-static PLINT      colorbar_option_kinds[COLORBAR_KINDS] = {
+static PLINT         colorbar_option_kinds[COLORBAR_KINDS] = {
     PL_COLORBAR_SHADE,
     PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL,
     PL_COLORBAR_IMAGE,
     PL_COLORBAR_GRADIENT
 };
-static const char *colorbar_option_kind_labels[COLORBAR_KINDS] = {
+static PLCHAR_VECTOR colorbar_option_kind_labels[COLORBAR_KINDS] = {
     "Shade colorbars",
     "Shade colorbars with custom labels",
     "Image colorbars",
@@ -82,13 +78,13 @@ static const char *colorbar_option_kind_labels[COLORBAR_KINDS] = {
 
 // Which side of the page are we positioned relative to?
 #define COLORBAR_POSITIONS    4
-static PLINT      colorbar_position_options[COLORBAR_POSITIONS] = {
+static PLINT         colorbar_position_options[COLORBAR_POSITIONS] = {
     PL_POSITION_LEFT,
     PL_POSITION_RIGHT,
     PL_POSITION_TOP,
     PL_POSITION_BOTTOM
 };
-static const char *colorbar_position_option_labels[COLORBAR_POSITIONS] = {
+static PLCHAR_VECTOR colorbar_position_option_labels[COLORBAR_POSITIONS] = {
     "Left",
     "Right",
     "Top",
@@ -97,13 +93,13 @@ static const char *colorbar_position_option_labels[COLORBAR_POSITIONS] = {
 
 // Colorbar label positioning options
 #define COLORBAR_LABELS    4
-static PLINT      colorbar_label_options[COLORBAR_LABELS] = {
+static PLINT         colorbar_label_options[COLORBAR_LABELS] = {
     PL_COLORBAR_LABEL_LEFT,
     PL_COLORBAR_LABEL_RIGHT,
     PL_COLORBAR_LABEL_TOP,
     PL_COLORBAR_LABEL_BOTTOM
 };
-static const char *colorbar_label_option_labels[COLORBAR_LABELS] = {
+static PLCHAR_VECTOR colorbar_label_option_labels[COLORBAR_LABELS] = {
     "Label left",
     "Label right",
     "Label top",
@@ -118,24 +114,24 @@ static PLINT         colorbar_cap_options[COLORBAR_CAPS] = {
     PL_COLORBAR_CAP_HIGH,
     PL_COLORBAR_CAP_LOW | PL_COLORBAR_CAP_HIGH
 };
-static const char    *colorbar_cap_option_labels[COLORBAR_CAPS] = {
+static PLCHAR_VECTOR colorbar_cap_option_labels[COLORBAR_CAPS] = {
     "No caps",
     "Low cap",
     "High cap",
     "Low and high caps"
 };
 
-static int           colorbar = 1; // By default do not plot plcolorbar pages
-                                   // for now while we are working out the API.
+static int           no_colorbar = 0; // By default plot plcolorbar pages
+
 static PLOptionTable options[] = {
     {
-        "colorbar",              // Turns on pages showing colorbars
+        "no_colorbar",              // Turns off pages showing colorbars
         NULL,
         NULL,
-        &colorbar,
+        &no_colorbar,
         PL_OPT_BOOL,
-        "-colorbar",
-        "Plot the \"color bar\" pages."
+        "-no_colorbar",
+        "Do not Plot the \"color bar\" pages."
     },
     {
         NULL,                   // option
@@ -148,27 +144,27 @@ static PLOptionTable options[] = {
     }                           // long syntax
 };
 
-const char           *notes[] = { "Make sure you get it right!", NULL };
+PLCHAR_VECTOR        notes[] = { "Make sure you get it right!", NULL };
 
 void
 plcolorbar_example_page( int kind_i, int label_i, int cap_i, PLINT cont_color, PLFLT cont_width, PLINT n_values, PLFLT *values )
 {
     // Parameters for the colorbars on this page
-    PLINT      position_i, position, opt;
-    PLFLT      x, y, x_length, y_length;
-    PLFLT      ticks[1]     = { 0.0 };
-    PLINT      sub_ticks[1] = { 0 };
-    PLFLT      low_cap_color, high_cap_color;
-    PLINT      vertical, ifn;
-    PLINT      n_axes = 1;
-    const char *axis_opts[1];
-    PLINT      n_labels      = 1;
-    PLINT      label_opts[1] = { 0 };
-    char       *label;
-    char       title[200];
-    PLFLT      colorbar_width, colorbar_height;
-    PLINT      n_values_array[1];
-    PLFLT      *values_array[1];
+    PLINT         position_i, position, opt;
+    PLFLT         x, y, x_length, y_length;
+    PLFLT         ticks[1]     = { 0.0 };
+    PLINT         sub_ticks[1] = { 0 };
+    PLFLT         low_cap_color, high_cap_color;
+    PLINT         vertical, ifn;
+    PLINT         n_axes = 1;
+    PLCHAR_VECTOR axis_opts[1];
+    PLINT         n_labels      = 1;
+    PLINT         label_opts[1] = { 0 };
+    char          *label;
+    char          title[200];
+    PLFLT         colorbar_width, colorbar_height;
+    PLINT         n_values_array[1];
+    PLFLT         *values_array[1];
 
     label = (char *) malloc( sizeof ( char ) * 200 );
 
@@ -257,10 +253,10 @@ plcolorbar_example_page( int kind_i, int label_i, int cap_i, PLINT cont_color, P
             15, 1, 1,
             low_cap_color, high_cap_color,
             cont_color, cont_width,
-            n_labels, label_opts, (const char **) &label,
+            n_labels, label_opts, (PLCHAR_MATRIX) &label,
             n_axes, axis_opts,
             ticks, sub_ticks,
-            n_values_array, (const PLFLT * const *) values_array );
+            n_values_array, (PLFLT_MATRIX) values_array );
 
         // Reset text and tick sizes
         plschr( 0.0, 1.0 );
@@ -275,10 +271,11 @@ plcolorbar_example_page( int kind_i, int label_i, int cap_i, PLINT cont_color, P
     plvpor( 0.0, 1.0, 0.0, 1.0 );
     plwind( 0.0, 1.0, 0.0, 1.0 );
     plptex( 0.5, 0.5, 0.0, 0.0, 0.5, title );
+    free( label );
 }
 
 void
-plcolorbar_example( const char *palette, int kind_i, PLINT cont_color, PLFLT cont_width, PLINT n_values, PLFLT *values )
+plcolorbar_example( PLCHAR_VECTOR palette, int kind_i, PLINT cont_color, PLFLT cont_width, PLINT n_values, PLFLT *values )
 {
     int label_i, cap_i;
 
@@ -305,27 +302,27 @@ plcolorbar_example( const char *palette, int kind_i, PLINT cont_color, PLFLT con
 #define MAX_NLEGEND    7
 
 int
-main( int argc, const char *argv[] )
+main( int argc, char *argv[] )
 {
-    int        i, k;
-    PLINT      opt;
-    PLINT      nlegend, nturn;
-    PLINT      opt_array[MAX_NLEGEND];
-    PLINT      text_colors[MAX_NLEGEND];
-    PLINT      box_colors[MAX_NLEGEND];
-    PLINT      box_patterns[MAX_NLEGEND];
-    PLFLT      box_scales[MAX_NLEGEND];
-    PLFLT      box_line_widths[MAX_NLEGEND];
-    PLINT      line_colors[MAX_NLEGEND];
-    PLINT      line_styles[MAX_NLEGEND];
-    PLFLT      line_widths[MAX_NLEGEND];
-    PLINT      symbol_numbers[MAX_NLEGEND], symbol_colors[MAX_NLEGEND];
-    PLFLT      symbol_scales[MAX_NLEGEND];
-    char       *text[MAX_NLEGEND];
-    const char *symbols[MAX_NLEGEND];
-    PLFLT      legend_width, legend_height, x, y, xstart, ystart;
-    PLFLT      max_height, text_scale;
-    PLINT      position, opt_base, nrow, ncolumn;
+    int           i, k;
+    PLINT         opt;
+    PLINT         nlegend, nturn;
+    PLINT         opt_array[MAX_NLEGEND];
+    PLINT         text_colors[MAX_NLEGEND];
+    PLINT         box_colors[MAX_NLEGEND];
+    PLINT         box_patterns[MAX_NLEGEND];
+    PLFLT         box_scales[MAX_NLEGEND];
+    PLFLT         box_line_widths[MAX_NLEGEND];
+    PLINT         line_colors[MAX_NLEGEND];
+    PLINT         line_styles[MAX_NLEGEND];
+    PLFLT         line_widths[MAX_NLEGEND];
+    PLINT         symbol_numbers[MAX_NLEGEND], symbol_colors[MAX_NLEGEND];
+    PLFLT         symbol_scales[MAX_NLEGEND];
+    char          *text[MAX_NLEGEND];
+    PLCHAR_VECTOR symbols[MAX_NLEGEND];
+    PLFLT         legend_width, legend_height, x, y, xstart, ystart;
+    PLFLT         max_height, text_scale;
+    PLINT         position, opt_base, nrow, ncolumn;
 
     // Create space to contain legend text.
     for ( k = 0; k < MAX_NLEGEND; k++ )
@@ -356,7 +353,7 @@ main( int argc, const char *argv[] )
     line_widths[0]    = 1.;
     symbol_scales[0]  = 1.;
     symbol_numbers[0] = 4;
-    symbols[0]        = "*";
+    symbols[0]        = "#(728)";
 
     // Use monotype fonts so that all legends are the same size.
     plsfont( PL_FCI_MONO, -1, -1 );
@@ -374,10 +371,10 @@ main( int argc, const char *argv[] )
         pllegend( &legend_width, &legend_height, opt, position, 0.05, 0.05,
             0.1, 15, 1, 1, 0, 0,
             nlegend, opt_array, 1.0, 1.0, 2.0,
-            1., text_colors, (const char * const *) text,
+            1., text_colors, (PLCHAR_MATRIX) text,
             NULL, NULL, NULL, NULL,
             line_colors, line_styles, line_widths,
-            symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+            symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
     }
 
     // Second page illustrating effect of nrow, ncolumn for the same legend
@@ -402,7 +399,7 @@ main( int argc, const char *argv[] )
         line_widths[k]    = 1.;
         symbol_scales[k]  = 1.;
         symbol_numbers[k] = 2;
-        symbols[k]        = "*";
+        symbols[k]        = "#(728)";
         sprintf( text[k], "%2.2d", k );
         text_colors[k]   = 1 + ( k % 8 );
         line_colors[k]   = 1 + ( k % 8 );
@@ -422,10 +419,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     position = PL_POSITION_BOTTOM | PL_POSITION_OUTSIDE;
     opt      = opt_base;
@@ -436,10 +433,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     position = PL_POSITION_LEFT | PL_POSITION_OUTSIDE;
     opt      = opt_base;
@@ -450,10 +447,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     position = PL_POSITION_RIGHT | PL_POSITION_OUTSIDE;
     opt      = opt_base;
@@ -464,10 +461,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     position = PL_POSITION_LEFT | PL_POSITION_TOP | PL_POSITION_INSIDE;
     opt      = opt_base;
@@ -478,10 +475,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     position = PL_POSITION_RIGHT | PL_POSITION_TOP | PL_POSITION_INSIDE;
     opt      = opt_base | PL_LEGEND_ROW_MAJOR;
@@ -492,10 +489,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     position = PL_POSITION_BOTTOM | PL_POSITION_INSIDE;
     opt      = opt_base | PL_LEGEND_ROW_MAJOR;
@@ -506,10 +503,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.05, 15, 1, 1, nrow, ncolumn,
         nlegend, opt_array, 1.0, 1.0, 2.0,
-        1., text_colors, (const char * const *) text,
+        1., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
     // Third page demonstrating legend alignment
     pladv( 0 );
@@ -542,7 +539,7 @@ main( int argc, const char *argv[] )
             line_widths[k]    = 1.;
             symbol_scales[k]  = 1.;
             symbol_numbers[k] = 2;
-            symbols[k]        = "*";
+            symbols[k]        = "#(728)";
             sprintf( text[k], "%2.2d", k );
             text_colors[k]   = 1 + ( k % 8 );
             line_colors[k]   = 1 + ( k % 8 );
@@ -558,10 +555,10 @@ main( int argc, const char *argv[] )
         pllegend( &legend_width, &legend_height, opt, position, x, y,
             0.025, 15, 1, 1, nrow, ncolumn,
             nlegend, opt_array, 1.0, 1.0, 1.5,
-            1., text_colors, (const char * const *) text,
+            1., text_colors, (PLCHAR_MATRIX) text,
             NULL, NULL, NULL, NULL,
             line_colors, line_styles, line_widths,
-            symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+            symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
 
         if ( i == nturn )
         {
@@ -642,10 +639,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         box_colors, box_patterns, box_scales, box_line_widths,
         line_colors, line_styles, line_widths,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
     max_height = MAX( max_height, legend_height );
 
     // Set up symbol legend entries with various symbols.
@@ -667,10 +664,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         NULL, NULL, NULL,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
     max_height = MAX( max_height, legend_height );
 
     // Set up symbol legend entries with various numbers of symbols.
@@ -692,10 +689,10 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         NULL, NULL, NULL,
-        symbol_colors, symbol_scales, symbol_numbers, (const char * const *) symbols );
+        symbol_colors, symbol_scales, symbol_numbers, (PLCHAR_MATRIX) symbols );
     max_height = MAX( max_height, legend_height );
 
     // Set up box legend entries with various colours.
@@ -720,7 +717,7 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         box_colors, box_patterns, box_scales, box_line_widths,
         NULL, NULL, NULL,
         NULL, NULL, NULL, NULL );
@@ -745,7 +742,7 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         box_colors, box_patterns, box_scales, box_line_widths,
         NULL, NULL, NULL,
         NULL, NULL, NULL, NULL );
@@ -770,7 +767,7 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         box_colors, box_patterns, box_scales, box_line_widths,
         NULL, NULL, NULL,
         NULL, NULL, NULL, NULL );
@@ -797,7 +794,7 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
         NULL, NULL, NULL, NULL );
@@ -821,7 +818,7 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
         NULL, NULL, NULL, NULL );
@@ -845,7 +842,7 @@ main( int argc, const char *argv[] )
     pllegend( &legend_width, &legend_height, opt, position, x, y,
         0.1, 15, 1, 1, 0, 0,
         nlegend, opt_array, 1.0, text_scale, 2.0,
-        0., text_colors, (const char * const *) text,
+        0., text_colors, (PLCHAR_MATRIX) text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
         NULL, NULL, NULL, NULL );
@@ -855,12 +852,12 @@ main( int argc, const char *argv[] )
     for ( k = 0; k < MAX_NLEGEND; k++ )
         free( (void *) text[k] );
 
-    if ( colorbar )
+    if ( !no_colorbar )
     {
         // Color bar examples
-        PLFLT values_small[2]  = { -1.0e-200, 1.0e-200 };
-        PLFLT values_uneven[9] = { -1.0e-200, 2.0e-200, 2.6e-200, 3.4e-200, 6.0e-200, 7.0e-200, 8.0e-200, 9.0e-200, 10.0e-200 };
-        PLFLT values_even[9]   = { -2.0e-200, -1.0e-200, 0.0e-200, 1.0e-200, 2.0e-200, 3.0e-200, 4.0e-200, 5.0e-200, 6.0e-200 };
+        PLFLT values_small[2]  = { -1.0e-20, 1.0e-20 };
+        PLFLT values_uneven[9] = { -1.0e-20, 2.0e-20, 2.6e-20, 3.4e-20, 6.0e-20, 7.0e-20, 8.0e-20, 9.0e-20, 10.0e-20 };
+        PLFLT values_even[9]   = { -2.0e-20, -1.0e-20, 0.0e-20, 1.0e-20, 2.0e-20, 3.0e-20, 4.0e-20, 5.0e-20, 6.0e-20 };
 
         // Use unsaturated green background colour to contrast with black caps.
         plscolbg( 70, 185, 70 );
